@@ -102,7 +102,7 @@ def get_param_grid_from_estimator(estimator):
     elif isinstance(estimator, boosting.LGBMegressor):
         param_grid = {
             "boosting_type":'gbdt',
-            "num_leaves":[31, 21, 41],
+            "num_leaves":[31,11,21,41],
             "max_depth":[-1,2,4,8,16],
             "learning_rate":[0.1,0.8, 0.5, 0.3, 0.01],
             "n_estimators":[100,200,500],
@@ -139,12 +139,45 @@ def get_param_grid_from_estimator(estimator):
     # elif isinstance(estimator, ensemble.BaggingRegressor):
     #     raise NotImplementedError()
         
-    # elif isinstance(estimator, ensemble.ExtraTreesRegressor):
-    #     raise NotImplementedError()        
-
-    # elif isinstance(estimator, ensemble.GradientBoostingRegressor):
-    #     raise NotImplementedError()
+    elif isinstance(estimator, ensemble.ExtraTreesRegressor):
+        param_grid = {
+            "n_estimators":500,                                                # Default 100 
+            'criterion':'squared_error',
+            'max_depth':[None,2,4,8,16],
+            'min_samples_split':[2,4,8,16],
+            'min_samples_leaf':[1,2,4,8],
+            'min_weight_fraction_leaf':0.0,
+            'max_features':['sqrt',1/4,1/3,1/2,2/3,'log2','auto'],             # Default 'auto'
+            'max_leaf_nodes':None,
+            'min_impurity_decrease':0.0,
+            'bootstrap':False,
+            'oob_score':False,
+            'ccp_alpha':0.0,
+            'max_samples':None
+            }   
 
+    elif isinstance(estimator, ensemble.GradientBoostingRegressor):
+        param_grid = {
+            "loss":'squared_error',
+            'learning_rate':[0.1,0.8, 0.5, 0.3, 0.01],
+            'n_estimators':[100,200,500],
+            'subsample':[1.0,0.8,0.5],
+            'criterion':'friedman_mse',
+            'min_samples_split':[2,4,8,16],
+            'min_samples_leaf':[1,2,4,8],
+            'min_weight_fraction_leaf':0.0,
+            'max_depth':[3,2,4,8,16],
+            'min_impurity_decrease':0.0,
+            'max_features':['sqrt',1/4,1/3,1/2,2/3,'log2',None],               # Default None
+            'alpha':0.9,
+            'verbose':0,
+            'max_leaf_nodes':None,
+            'validation_fraction':0.1,
+            'n_iter_no_change':None,
+            'tol':0.0001,
+            'ccp_alpha':0.0
+            }
+        
     elif isinstance(estimator, ensemble.RandomForestRegressor):
         param_grid = {
             "n_estimators":500,                                                # Default 100 
@@ -153,7 +186,7 @@ def get_param_grid_from_estimator(estimator):
             "min_samples_split":[2,4,8,16],
             "min_samples_leaf":[1,2,4,8],
             "min_weight_fraction_leaf":0.0,
-            "max_features":['sqrt',1/4,1/3,1/2,2/3,'log2','auto'],             # Default 100
+            "max_features":['sqrt',1/4,1/3,1/2,2/3,'log2','auto'],             # Default 'auto'
             "max_leaf_nodes":None,
             "min_impurity_decrease":0.0,
             "bootstrap":True,
@@ -166,8 +199,8 @@ def get_param_grid_from_estimator(estimator):
             "max_samples":None
             }
 
-    elif isinstance(estimator, ensemble.HistGradientBoostingRegressor):
-        raise NotImplementedError()    
+    # elif isinstance(estimator, ensemble.HistGradientBoostingRegressor):
+    #     raise NotImplementedError()    
 
     #--------------------------------------------------------------------------
     # from sklearn.gaussian_process
@@ -198,25 +231,130 @@ def get_param_grid_from_estimator(estimator):
             "n_jobs":None,
             "positive":False
             }
+                
+    elif isinstance(estimator, linear_model.Ridge):
+        param_grid = {
+            'alpha':[1.0,0.001, 0.1, 10, 100, 1000, 10000], 
+            'fit_intercept':True,
+            'copy_X':True,
+            'max_iter':None,
+            'tol':0.001,
+            'solver':'auto',
+            'positive':False,
+            'random_state':None
+            }
+        
+    elif isinstance(estimator, linear_model.RidgeCV):
+        param_grid = {
+            'alphas':(1.0,0.001, 0.1, 10, 100, 1000, 10000),
+            'fit_intercept':True,
+            'scoring':None,
+            'gcv_mode':None,
+            'store_cv_values':False,
+            'alpha_per_target':False
+            }
         
-    # elif isinstance(estimator, linear_model.Ridge):
-    #     raise NotImplementedError()            
-
     # elif isinstance(estimator, linear_model.SGDRegressor):
     #     raise NotImplementedError()    
         
-    # elif isinstance(estimator, linear_model.ElasticNet):
-    #     raise NotImplementedError()    
+    elif isinstance(estimator, linear_model.ElasticNet):
+        param_grid = {
+            'alpha':np.exp(np.linspace(start=np.log(100), stop=np.log(100*0.000001), num=1000)),
+            'l1_ratio':[0.5,1/4,3/4,1],
+            'fit_intercept':True,
+            'precompute':False,
+            'max_iter':1000,
+            'tol':0.0001,
+            'warm_start':False,
+            'positive':False,
+            'selection':'cyclic'
+            }
 
-    # elif isinstance(estimator, linear_model.Lars):
-    #     raise NotImplementedError()    
+    elif isinstance(estimator, linear_model.ElasticNetCV):
+        param_grid = {
+            'l1_ratio':[0.5,1/4,3/4,1],
+            'eps':0.001,
+            'n_alphas':1000,
+            'fit_intercept':True,
+            'precompute':'auto',
+            'max_iter':1000,
+            'tol':0.0001,
+            'copy_X':True,
+            'positive':False,
+            'selection':'cyclic'
+            }
 
-    # elif isinstance(estimator, linear_model.Lasso):
-    #     raise NotImplementedError()    
+    elif isinstance(estimator, linear_model.Lars):
+        param_grid = {
+            'fit_intercept':True,
+            'precompute':'auto',
+            'n_nonzero_coefs':[500,100,200,300,400,np.inf],
+            'eps':2.220446049250313e-16,
+            'copy_X':True,
+            'fit_path':True,
+            'jitter':None,
+            }
 
-    # elif isinstance(estimator, linear_model.LassoLars):
-    #     raise NotImplementedError()    
+    elif isinstance(estimator, linear_model.LarsCV):
+        param_grid = {
+            'fit_intercept':True,
+            'max_iter':500,
+            'precompute':'auto',
+            'max_n_alphas':1000,
+            'eps':2.220446049250313e-16,
+            'copy_X':True
+            }
+        
+    elif isinstance(estimator, linear_model.Lasso):
+        param_grid = {
+            'alpha':np.exp(np.linspace(start=np.log(100), stop=np.log(100*0.000001), num=1000)),
+            'fit_intercept':True,
+            'precompute':False,
+            'copy_X':True,
+            'max_iter':1000,
+            'tol':0.0001,
+            'warm_start':False,
+            'positive':False,
+            'selection':'cyclic'
+            }
 
+    elif isinstance(estimator, linear_model.LassoCV):
+        param_grid = {
+            'eps':0.001,
+            'n_alphas':1000,
+            'fit_intercept':True,
+            'precompute':'auto',
+            'max_iter':1000,
+            'tol':0.0001,
+            'copy_X':True,
+            'positive':False,
+            'selection':'cyclic'
+            }
+
+    elif isinstance(estimator, linear_model.LassoLars):
+        param_grid = {
+            'alpha':np.exp(np.linspace(start=np.log(100), stop=np.log(100*0.000001), num=1000)),
+            'fit_intercept':True,
+            'precompute':'auto',
+            'max_iter':500,
+            'eps':2.220446049250313e-16,
+            'copy_X':True,
+            'fit_path':True,
+            'positive':False,
+            'jitter':None,
+            }
+
+    elif isinstance(estimator, linear_model.LassoLarsCV):
+        param_grid = {
+            'fit_intercept':True,
+            'max_iter':500,
+            'precompute':'auto',
+            'max_n_alphas':1000,
+            'eps':2.220446049250313e-16,
+            'copy_X':True,
+            'positive':False
+            }
+        
     # elif isinstance(estimator, linear_model.OrthogonalMatchingPursuit):
     #     raise NotImplementedError()            
         
@@ -245,7 +383,34 @@ def get_param_grid_from_estimator(estimator):
     #--------------------------------------------------------------------------
     # from sklearn.neural_network
     #--------------------------------------------------------------------------
-    
+    elif isinstance(estimator, neural_network.MLPRegressor):
+        param_grid = {
+            'hidden_layer_sizes':[(100,), (2,), (2,4), (2,4,8,), (2,4,8,16,), (2,4,8,16,32),
+                                          (4,), (4,8), (4,8,16), (4,8,16,32),
+                                          (8,), (8,16), (8,16,32),
+                                          (16,), (16,32),
+                                          (32,)],
+            'activation':'relu',
+            'solver':'adam',
+            'alpha':[0.0001,1.e+01, 1.e+02, 1.e+03, 1.e+05, 1.e+06],
+            'batch_size':'auto',
+            'learning_rate':['constant', 'invscaling', 'adaptive'],
+            'learning_rate_init':0.001,
+            'power_t':0.5,
+            'max_iter':200,
+            'shuffle':True,
+            'tol':0.0001,
+            'momentum':0.9,
+            'nesterovs_momentum':True,
+            'early_stopping':True,
+            'validation_fraction':0.1,
+            'beta_1':0.9,
+            'beta_2':0.999,
+            'epsilon':1e-08,
+            'n_iter_no_change':10,
+            'max_fun':15000
+            }
+        
     #--------------------------------------------------------------------------
     # from sklearn.svm
     #--------------------------------------------------------------------------
@@ -266,84 +431,6 @@ def get_param_grid_from_estimator(estimator):
     return param_grid
 
   
-
-    # # Lasso
-    # lambda_max = (X.T @ y.values).abs().max()/X.shape[0]
-     
-    #     "Lasso" : {
-    #         "model_params" : {
-    #             "fit_intercept":True,
-    #             "normalize":False,
-    #             "precompute":False,
-    #             "copy_X":True,
-    #             "max_iter":100000,
-    #             "tol":0.0001,
-    #             "warm_start":False,
-    #             "positive":False,
-    #             "random_state":None,
-    #             "selection":'cyclic'
-    #             },
-    #         "tuning_params" : {
-    #             "alpha": np.exp(np.linspace(start=np.log(lambda_max), stop=np.log(lambda_max*0.000001), num=1000))
-    #             }
-    #     },
-    #     "Ridge" : {
-    #         "model_params" : {
-    #             "fit_intercept":True,
-    #             "normalize":False,
-    #             "copy_X":True,
-    #             "max_iter":None,
-    #             "tol":0.0001,
-    #             "solver":'auto',
-    #             "random_state":None,
-    #             },
-    #         "tuning_params" : {
-    #             "alpha": [0.001, 0.1, 1, 10, 100, 1000, 10000]
-    #             }
-    #     },
-    #     "ElasticNet" : {
-    #         "model_params" : {
-    #             "fit_intercept":True,
-    #             "normalize":False,
-    #             "precompute":False,
-    #             "max_iter":100000,
-    #             "copy_X":True,
-    #             "tol":0.0001,
-    #             "warm_start":False,
-    #             "positive":False,
-    #             "random_state":None,
-    #             "selection":'cyclic'
-    #             },
-    #         "tuning_params" : {
-    #             "alpha": np.exp(np.linspace(start=np.log(lambda_max), stop=np.log(lambda_max*0.000001), num=1000)),
-    #             "l1_ratio": [1/4, 1/2, 3/4, 1]
-    #             }
-    #     },
-
-    #     },
-    #     "ExtraTreesRegressor" : {
-    #         "model_params" : {
-    #             "criterion":'mse',
-    #             "min_weight_fraction_leaf":0.0,
-    #             'min_impurity_decrease':0.0,
-    #             'min_impurity_split':None,
-    #             'bootstrap': True,
-    #             'oob_score':False,
-    #             'n_jobs':None,
-    #             'random_state':None,
-    #             'verbose':0,
-    #             'warm_start':False,
-    #             'ccp_alpha':0.0,
-    #             'max_samples':None
-    #             },
-    #         "tuning_params" : {
-    #             'n_estimators': 500,
-    #             'min_samples_split': [2,4,8,16],
-    #             'min_samples_leaf': [1,2,4,8],
-    #             'max_features': [1/4,1/3,1/2,2/3, 'sqrt','log2'],
-    #             'max_leaf_nodes': None,
-    #             'max_depth': [4,8,16,None]
-    #             }
     #     },
     #     "SGDRegressor" : {
     #         "model_params" : {
@@ -484,39 +571,7 @@ def get_param_grid_from_estimator(estimator):
     #             "n_neighbors":[5,1,2,4,8,16,32],
     #             "weights":['distance','uniform'],
     #             }
-    #     },
-    #     "MLPRegressor" : {
-    #         "model_params" : {
-    #             "solver":'adam',
-    #             "batch_size":'auto',
-    #             "learning_rate_init":0.001,
-    #             "power_t":0.5,
-    #             "max_iter":10000,
-    #             "shuffle":True,
-    #             "random_state":None,
-    #             "tol":0.0001,
-    #             "verbose":False,
-    #             "warm_start":False,
-    #             "momentum":0.9,
-    #             "nesterovs_momentum":True,
-    #             "early_stopping":True,
-    #             "validation_fraction":0.1,
-    #             "beta_1":0.9,
-    #             "beta_2":0.999,
-    #             "epsilon":1e-08,
-    #             "n_iter_no_change":50,
-    #             "max_fun":15000
-    #             },
-    #         "tuning_params" : {
-    #             "hidden_layer_sizes":[(2,), (2,4), (2,4,8,), (2,4,8,16,), (2,4,8,16,32),
-    #                                   (4,), (4,8), (4,8,16), (4,8,16,32),
-    #                                   (8,), (8,16), (8,16,32),
-    #                                   (16,), (16,32),
-    #                                   (32,)],
-    #             "activation":['relu'],
-    #             "alpha":[1.e+01, 1.e+02, 1.e+03, 1.e+04, 1.e+05, 1.e+06],
-    #             "learning_rate":['constant', 'adaptive'],
-    #             }
+    #
     #     },
     #     "LinearSVR" : {
     #         "model_params" : {
